Messages: Replaced some 'Available' by 'Existing'.
--- a/po/vmm.pot Sun Oct 16 15:08:25 2011 +0000
+++ b/po/vmm.pot Sun Oct 16 16:48:48 2011 +0000
@@ -8,7 +8,7 @@
msgstr ""
"Project-Id-Version: vmm 0.6.0\n"
"Report-Msgid-Bugs-To: neverseen@users.sourceforge.net\n"
-"POT-Creation-Date: 2011-10-16 17:00+0200\n"
+"POT-Creation-Date: 2011-10-16 18:44+0200\n"
"PO-Revision-Date: YEAR-MO-DA HO:MI+ZONE\n"
"Last-Translator: FULL NAME <EMAIL@ADDRESS>\n"
"Language-Team: LANGUAGE <LL@li.org>\n"
@@ -722,9 +722,9 @@
msgid "information"
msgstr ""
-#. TP: used in e.g. 'Available alias addresses' or 'Available accounts'
+#. TP: used in e.g. 'Existing alias addresses' or 'Existing accounts'
#: VirtualMailManager/cli/subcommands.py:788
-msgid "Available"
+msgid "Existing"
msgstr ""
#: VirtualMailManager/cli/subcommands.py:801
@@ -755,7 +755,7 @@
msgstr ""
#: VirtualMailManager/cli/subcommands.py:834
-msgid "Available domains"
+msgid "Existing domains"
msgstr ""
#: VirtualMailManager/cli/subcommands.py:849
--- a/VirtualMailManager/cli/subcommands.py Sun Oct 16 15:08:25 2011 +0000
+++ b/VirtualMailManager/cli/subcommands.py Sun Oct 16 16:48:48 2011 +0000
@@ -784,8 +784,8 @@
def _print_list(alist, title):
"""Print a list."""
- # TP: used in e.g. 'Available alias addresses' or 'Available accounts'
- msg = u'%s %s' % (_(u'Available'), title)
+ # TP: used in e.g. 'Existing alias addresses' or 'Existing accounts'
+ msg = u'%s %s' % (_(u'Existing'), title)
w_std(msg, u'-' * len(msg))
if alist:
if title != _(u'alias domains'):
@@ -831,7 +831,7 @@
if matching:
title = _(u'Matching domains')
else:
- title = _(u'Available domains')
+ title = _(u'Existing domains')
w_std(title, '-' * len(title))
if domains:
for did in dids: